package com.qmth.digit.print.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.digit.print.common.enums.*;
import com.qmth.digit.print.common.enums.result.EnumResult;
import io.swagger.annotations.Api;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 枚举类型查询接口
 *
 * @Date: 2021/3/29.
 */
@Api(tags = "枚举类型Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.common}/get_enums")
@Aac(auth = BOOL.FALSE)
public class EnumsController {

    /**
     * 查询
     *
     * @param type
     * @return
     */
    @RequestMapping(method = RequestMethod.GET)
    public List<EnumResult> list(String type) {
        if (StringUtils.isBlank(type)) {
            throw ExceptionResultEnum.ERROR.exception("类型不能为空");
        }

        if (type.equals(EnumType.BACKUP_METHOD.name())) {
            //备份方式
            return BackupMethodEnum.listTypes();
        } else if (type.equals(EnumType.CLASSIFY.name())) {
            //模板类型
            return ClassifyEnum.listTypes();
        } else if (type.equals(EnumType.DRAW_RULE.name())) {
            // 抽卷规则
            return DrawRuleEnum.listTypes();
        } else if (type.equals(EnumType.EXAM_NUMBER_STYLE.name())) {
            //考号版式
            return ExamNumberStyleEnum.listTypes();
        } else if (type.equals(EnumType.EXAM_STATUS.name())) {
            //命题状态类型
            return ExamStatusEnum.listTypes();
        } else if (type.equals(EnumType.PAPER_TYPE.name())) {
            //AB卷版式
            return PaperTypeEnum.listTypes();
        } else if (type.equals(EnumType.PRINT_METHOD.name())) {
            //印刷方式
            return PrintMethodEnum.listTypes();
        } else if (type.equals(EnumType.PRIVILEGE_TYPE.name())) {
            //菜单类型
            return PrivilegeTypeEnum.listTypes();
        } else if (type.equals(EnumType.REQUIRED_FIELDS.name())) {
            //考务必选字段
            return RequiredFieldsEnum.listTypes();
        } else if (type.equals(EnumType.REVIEW_STATUS.name())) {
            //审核状态类型
            return ReviewStatusEnum.listTypes();
        } else if (type.equals(EnumType.ROLE_TYPE.name())) {
            //内置角色类型
            return RoleTypeEnum.listTypes(false);
        } else if (type.equals(EnumType.STORAGE_LEVEL.name())) {
            //附件存储级别
            return StorageLevelEnum.listTypes();
        } else if (type.equals(EnumType.STORAGE_TYPE.name())) {
            //附件存储方式
            return StorageTypeEnum.listTypes();
        } else if (type.equals(EnumType.TEMPLATE_TYPE.name())) {
            return TemplateTypeEnum.listTypes();
            //模板类型
        } else {
            return null;
        }
    }
}
